@@ -1,8 +1,7 @@
-
 #
-# $Id: Fasta.pm,v 1.14 2001/01/28 06:45:08 lapp Exp $
+# $Id: Fasta.pm,v 1.18 2001/12/06 22:03:11 jason Exp $
 #
-# BioPerl module for Bio::Index::Abstract
+# BioPerl module for Bio::Index::Fasta
 #
 # Cared for by James Gilbert <jgrg@sanger.ac.uk>
 #
@@ -22,8 +21,8 @@ Bio::Index::Fasta - Interface for indexing (multiple) fasta files
 
     my $Index_File_Name = shift;
     my $inx = Bio::Index::Fasta->new(
-        -filename => $Index_File_Name,
-        -write_flag => 1);
+        '-filename' => $Index_File_Name,
+        '-write_flag' => 1);
     $inx->make_index(@ARGV);
 
     # Print out several sequences present in the index
@@ -31,7 +30,7 @@ Bio::Index::Fasta - Interface for indexing (multiple) fasta files
     use Bio::Index::Fasta;
 
     my $Index_File_Name = shift;
-    my $inx = Bio::Index::Fasta->new($Index_File_Name);
+    my $inx = Bio::Index::Fasta->new('-filename' => $Index_File_Name);
     my $out = Bio::SeqIO->new('-format' => 'Fasta','-fh' => \*STDOUT);
 
     foreach my $id (@ARGV) {
@@ -145,7 +144,6 @@ sub _index_file {
     
     my( $begin,     # Offset from start of file of the start
                     # of the last found record.
-        @id_list,   # List of ids from last record
         );
 
     $begin = 0;
@@ -159,9 +157,9 @@ sub _index_file {
         if (/^>/) {
             # $begin is the position of the first character after the '>'
             my $begin = tell(FASTA) - length( $_ ) + 1;
-
+	    
             foreach my $id (&$id_parser($_)) {
-                $self->add_record($id, $i, $begin);
+		$self->add_record($id, $i, $begin);
             }
         }
     }
@@ -221,6 +219,3 @@ sub default_id_parser {
 }
 
 1;
-
-
-
