@@ -1,4 +1,4 @@
-# $Id: SimpleAlign.pm,v 1.49.2.3 2002/03/18 14:31:08 jason Exp $
+# $Id: SimpleAlign.pm,v 1.49.2.6 2002/06/07 10:30:44 heikki Exp $
 # BioPerl module for SimpleAlign
 #
 # Cared for by Heikki Lehvaslaiho <heikki@ebi.ac.uk>
@@ -118,6 +118,7 @@ Ewan Birney, birney@sanger.ac.uk
 David J. Evans, David.Evans@vir.gla.ac.uk
 Heikki Lehvaslaiho, heikki@ebi.ac.uk
 Jason Stajich, jason@bioperl.org
+Xintao Wei & Giri Narasimhan, giri@cs.fiu.edu
 
 =head1 SEE ALSO
 
@@ -1275,6 +1276,7 @@ sub _consensus_iupac {
 	$string =~ s/S/GC/;
 	$string =~ s/K/GT/;
 	$string =~ s/Y/CT/;
+	$string =~ s/R/AG/;
 	$string =~ s/W/AT/;
 	$string =~ s/M/AC/;
     }
@@ -1489,7 +1491,7 @@ sub no_sequences {
 # This method implemented by Kevin Howe calculates a figure that is 
 # designed to be similar to the average pairwise identity of the 
 # alignment (identical in the absence of gaps), without having to
-# explicitly calculate pairwise idenities proposed by Richard Durbin.
+# explicitly calculate pairwise identities proposed by Richard Durbin.
 # Validated by Ewan Birney ad Alex Bateman.
 
 =head2 average_percentage_identity
