@@ -14,20 +14,21 @@ Bio::Tools::Alignment::Consed - A module to work with objects from consed .ace f
 
 =head1 SYNOPSIS
 
-        # a report for sequencing stuff
-my $o_consed = new Bio::Tools::Alignment::Consed( -acefile => "/path/to/an/acefile.ace.1",
-				-verbose => 1);
-my $foo = $o_consed->set_reverse_designator("r");
-my $bar = $o_consed->set_forward_designator("f");
+  # a report for sequencing stuff
+  my $o_consed = new Bio::Tools::Alignment::Consed
+        ( -acefile => "/path/to/an/acefile.ace.1",
+	  -verbose => 1);
+  my $foo = $o_consed->set_reverse_designator("r");
+  my $bar = $o_consed->set_forward_designator("f");
 
-        # get the contig numbers
-my @keys = $o_consed->get_contigs();
+  # get the contig numbers
+  my @keys = $o_consed->get_contigs();
 
-        # construct the doublets
-my $setter_doublets = $o_consed->choose_doublets();
+  # construct the doublets
+  my $setter_doublets = $o_consed->choose_doublets();
 
-        # get the doublets
-my @doublets = $o_consed->get_doublets();
+  # get the doublets
+  my @doublets = $o_consed->get_doublets();
 
 =head1 DESCRIPTION
 
@@ -212,28 +213,50 @@ sub get_filename {
 	   this. It is more of a debugging routine designed to address very
 	   specific problems.
 
+           This method was reimplemented to be platform independent with a 
+           pure perl implementation.  The above note can be ignored.
+
 =cut
 
 sub count_sequences_with_grep {
     my $self = shift;
     my ($working_dir,$grep_cli,@total_grep_sequences);
-    	# I tried to cause graceful exiting if not on *ix here
-    	# then i took platforms from Bioperl*/PLATFORMS here. Is that good?
-    	# print("\$^O is $^O\n");
-    if (!($^O =~ /dec_osf|linux|unix|bsd|solaris/i)) {
-	$self->warn("Bio::Tools::Alignment::Consed::count_sequences_with_grep: This sub uses grep which is doesn't run on this operating system, AFAIK. Sorry   .".$^O);
-	return 1;
+    # this should be migrated to a pure perl implementation ala
+    # Tom Christiansen's 'tcgrep'
+    # http://www.perl.com/language/ppt/src/grep/tcgrep
+    
+    open(FILE, $self->{'filename'}) or do { $self->warn("cannot open file ".$self->{'filename'}. " for grepping"); return}; 
+    my $counter =0;
+    while(<FILE>) { $counter++ if(/^AF/); }
+
+    close FILE;
+    opendir(SINGLETS,$self->{'path'});
+    foreach my $f ( readdir(SINGLETS) ) {
+	next unless ($f =~ /\.singlets$/); 
+	open(FILE, $self->catfile($self->{'path'},$f)) or do{ $self->warn("cannot open file ".$self->catfile($self->{'path'},$f)); next };
+	while(<FILE>) { $counter++ if(/^>/) }
+	close FILE;
     }
-    $grep_cli = `which grep`;
-    if (!$grep_cli) {
-	$self->warn("I couldn't see to find grep on this system, or the which command is broken. Bio::Tools::Alignment::Consed::count_sequences_with_grep requires grep and which to find grep.");
-	return 1;
-    }
-    chomp $grep_cli;
-    push(@total_grep_sequences, my @foo = `$grep_cli ^AF $self->{filename}`);
-    my $cli = "$grep_cli \\> $self->{'path'}*.singlets";
-    push(@total_grep_sequences, @foo = `$cli`);
-    return scalar(@total_grep_sequences);
+    return $counter;
+# Chad's platform implementation which required grep on the system
+
+    # I tried to cause graceful exiting if not on *ix here
+    # then i took platforms from Bioperl*/PLATFORMS here. Is that good?
+    # print("\$^O is $^O\n");
+#	if (!($^O =~ /dec_osf|linux|unix|bsd|solaris|darwin/i)) {
+#	$self->warn("Bio::Tools::Alignment::Consed::count_sequences_with_grep: This sub uses grep which is doesn't run on this operating system, AFAIK. Sorry   .".$^O);
+#	return 1;
+#    }    
+#    $grep_cli = `which grep`;
+#    if (!$grep_cli) {
+#	$self->warn("I couldn't see to find grep on this system, or the which command is broken. Bio::Tools::Alignment::Consed::count_sequences_with_grep requires grep and which to find grep.");
+#	return 1;
+#    }
+#    chomp $grep_cli;
+#    push(@total_grep_sequences, my @foo = `$grep_cli ^AF $self->{filename}`);
+#    my $cli = "$grep_cli \\> $self->{'path'}*.singlets";
+#    push(@total_grep_sequences, @foo = `$cli`);
+#    return scalar(@total_grep_sequences);
 }
 
 =head2 get_path()
