@@ -1,4 +1,4 @@
-## $Id: pSW.pm,v 1.9.2.3 2001/03/30 07:23:16 lapp Exp $
+## $Id: pSW.pm,v 1.19 2002/01/23 11:30:27 heikki Exp $
 
 #
 # BioPerl module for Bio::Tools::pSW
@@ -17,10 +17,12 @@ Bio::Tools::pSW - pairwise Smith Waterman object
 
 =head1 SYNOPSIS
 
-    $factory = new Bio::Tools::pSW( '-matrix' => 'blosum62.bla',
-				    '-gap' => 12,
-				    '-ext' => 2,
-				   );
+    use Bio::Tools::pSW;
+    use Bio::AlignIO;
+    my $factory = new Bio::Tools::pSW( '-matrix' => 'blosum62.bla',
+				       '-gap' => 12,
+				       '-ext' => 2,
+				       );
 
     #use the factory to make some output
 
@@ -28,9 +30,11 @@ Bio::Tools::pSW - pairwise Smith Waterman object
 
     # make a Bio::SimpleAlign and do something with it
 
-    $aln = $factory->pairwise_alignment($seq1,$seq2);
+    my $aln = $factory->pairwise_alignment($seq1,$seq2);
+    my $alnout = new Bio::AlignIO(-format => 'msf',
+				  -fh     => \*STDOUT);
 
-    $aln->write_MSF(\*STDOUT);
+    $alnout->write_aln($aln);
 
 =head1 INSTALLATION
 
@@ -79,39 +83,46 @@ warning - this module is under active development. Eventually it should
 contain the ability to make alignment objects such as Bio::SimpleAlign
 or Bio::UnivAlign 
 
+(Which has been done as of bioperl 0.7 series)
+
+
 =head1 FEEDBACK
 
 =head2 Mailing Lists 
 
-User feedback is an integral part of the evolution of this and other Bioperl modules.
-Send your comments and suggestions preferably to one of the Bioperl mailing lists.
-Your participation is much appreciated.
+User feedback is an integral part of the evolution of this and other
+Bioperl modules.  Send your comments and suggestions preferably to one
+of the Bioperl mailing lists.  Your participation is much appreciated.
 
     bioperl-l@bioperl.org              - General discussion
     http://bioperl.org/MailList.shtml  - About the mailing lists
 
 =head2 Reporting Bugs
 
-Report bugs to the Bioperl bug tracking system to help us keep track the bugs and 
-their resolution. Bug reports can be submitted via email or the web:
+Report bugs to the Bioperl bug tracking system to help us keep track
+the bugs and their resolution. Bug reports can be submitted via email
+or the web:
 
     bioperl-bugs@bio.perl.org                   
     http://bioperl.org/bioperl-bugs/           
 
 =head1 AUTHOR
 
-Ewan Birney, birney@sanger.ac.uk
+Ewan Birney, birney@sanger.ac.uk or birney@ebi.ac.uk
+
+=head1 CONTRIBUTORS
+
+Jason Stajich, jason@bioperl.org
 
 =head1 APPENDIX
 
-The rest of the documentation details each of the object methods. Internal methods are usually preceded with an underscore "_".
+The rest of the documentation details each of the object
+methods. Internal methods are usually preceded with an underscore "_".
 
 =cut
 
-
 # Let the code begin...
 
-
 package Bio::Tools::pSW;
 use vars qw(@ISA);
 use strict;
@@ -134,22 +145,17 @@ use Bio::SimpleAlign;
 @ISA = qw(Bio::Tools::AlignFactory);
 
 
-# new() is inherited from Bio::Root::Object
-
-# _initialize is where the heavy stuff will happen when new is called
-
-sub _initialize {
-  my($self,@p) = @_;
-
 
+sub new {
+  my($class,@args) = @_;
+  
+  my $self = $class->SUPER::new(@args);
 
   my($matrix,$gap,$ext) = $self->_rearrange([qw(MATRIX
 						GAP
 						EXT
-						)],@p);
+						)],@args);
   
-  my $make = $self->SUPER::_initialize(@p);
-
   #default values - we have to load matrix into memory, so 
   # we need to check it out now
   if( ! defined $matrix || !($matrix =~ /\w/) ) {
@@ -157,22 +163,27 @@ sub _initialize {
   }
 
   $self->matrix($matrix); # will throw exception if it can't load it
-  $self->gap(12);
-  $self->ext(2);
+  $self->gap(12) unless defined $gap;
+  $self->ext(2) unless defined $ext;
 
-  #I'm pretty sure I am not doing this right... ho hum...
-
-  if( $gap ) {
-      $gap =~ /^\d+$/ || $self->throw("Gap penalty must be a number, not [$gap]");
-      $self->gap($gap);
+  # I'm pretty sure I am not doing this right... ho hum...
+  # This was not roght ($gap and $ext could not be 0) It is fixed now /AE
+  if(  defined $gap ) {
+      if( $gap =~ /^\d+$/ ) {
+	  $self->gap($gap);
+      } else {
+	  $self->throw("Gap penalty must be a number, not [$gap]");
+      }
   }
-
-  if( $ext ) {
-      $ext =~ /^\d+$/ || $self->throw("Extension penalty must be a number, not [$ext]");
-      $self->ext($ext);
+  if( defined $ext ) {
+      if( $ext =~ /^\d+$/ )  {
+	  $self->ext($ext);
+      } else {
+	  $self->throw("Extension penalty must be a number, not [$ext]");
+      }
   }
-
-  return $make; # success - we hope!
+ 
+  return $self; 
 }
 
 
@@ -190,18 +201,32 @@ sub _initialize {
 sub pairwise_alignment{
     my ($self,$seq1,$seq2) = @_;
     my($t1,$t2,$aln,$out,@str1,@str2,@ostr1,@ostr2,$alc,$tstr,$tid,$start1,$end1,$start2,$end2,$alctemp);
-
+    
+    if( ! defined $seq1 || ! $seq1->isa('Bio::PrimarySeqI') ||
+	! defined $seq2 || ! $seq2->isa('Bio::PrimarySeqI') ) {
+	$self->warn("Cannot call pairwise_alignment without specifing 2 sequences (Bio::PrimarySeqI objects)");
+	return undef;
+    }
+    # fix Jitterbug #1044
+    if( $seq1->length() < 2 || 
+	$seq2->length() < 2 ) {
+	$self->warn("cannot align sequences with length less than 2");
+	return undef;
+    }
     $self->set_memory_and_report();
     # create engine objects 
+    $seq1->display_id('seq1') unless ( defined $seq1->id() );
+    $seq2->display_id('seq2') unless ( defined $seq2->id() );
 
-    $t1  = &Bio::Ext::Align::new_Sequence_from_strings($seq1->id(),$seq1->seq());
-    $t2  = &Bio::Ext::Align::new_Sequence_from_strings($seq2->id(),$seq2->seq());
+    $t1  = &Bio::Ext::Align::new_Sequence_from_strings($seq1->id(),
+						       $seq1->seq());
+    $t2  = &Bio::Ext::Align::new_Sequence_from_strings($seq2->id(),
+						       $seq2->seq());
     $aln = &Bio::Ext::Align::Align_Sequences_ProteinSmithWaterman($t1,$t2,$self->{'matrix'},-$self->gap,-$self->ext);
     if( ! defined $aln || $aln == 0 ) {
 	$self->throw("Unable to build an alignment");
     }
 
-
     # free sequence engine objects
 
     $t1 = $t2 = 0;
@@ -261,14 +286,14 @@ sub pairwise_alignment{
 
     $tstr = join('',@ostr1);
     $tid = $seq1->id();
-    $out->addSeq(Bio::LocatableSeq->new( -seq=> $tstr,
+    $out->add_seq(Bio::LocatableSeq->new( -seq=> $tstr,
 					 -start => $start1,
 					 -end   => $end1,
 					 -id=>$tid ));
 
     $tstr = join('',@ostr2);
     $tid = $seq2->id();
-    $out->addSeq(Bio::LocatableSeq->new( -seq=> $tstr,
+    $out->add_seq(Bio::LocatableSeq->new( -seq=> $tstr,
 					 -start => $start2,
 					 -end => $end2,
 					 -id=> $tid ));
@@ -289,7 +314,23 @@ sub align_and_show {
     my($self,$seq1,$seq2,$fh) = @_;
     my($t1,$t2,$aln,$id,$str);
 
+if( ! defined $seq1 || ! $seq1->isa('Bio::PrimarySeqI') ||
+	! defined $seq2 || ! $seq2->isa('Bio::PrimarySeqI') ) {
+	$self->warn("Cannot call align_and_show without specifing 2 sequences (Bio::PrimarySeqI objects)");
+	return undef;
+    }
+    # fix Jitterbug #1044
+    if( $seq1->length() < 2 || 
+	$seq2->length() < 2 ) {
+	$self->warn("cannot align sequences with length less than 2");
+	return undef;
+    }
+    if( ! defined $fh ) { 
+	$fh = \*STDOUT;
+    }
     $self->set_memory_and_report();
+    $seq1->display_id('seq1') unless ( defined $seq1->id() );
+    $seq2->display_id('seq2') unless ( defined $seq2->id() );
 
     $t1  = &Bio::Ext::Align::new_Sequence_from_strings($seq1->id(),$seq1->seq());
 
@@ -352,7 +393,7 @@ sub gap {
     
 
     if( defined $val ) {
-	if( $val <= 0 ) {
+	if( $val < 0 ) {    # Fixed so that gap==0 is allowed /AE
 	    $self->throw("Can't have a gap penalty less than 0");
 	}
 	$self->{'gap'} = $val;
@@ -377,7 +418,7 @@ sub ext {
     my ($self,$val) = @_;
     
     if( defined $val ) {
-	if( $val <= 0 ) {
+	if( $val < 0 ) {    # Fixed so that gap==0 is allowed /AE
 	    $self->throw("Can't have a gap penalty less than 0");
 	}
 	$self->{'ext'} = $val;
